@@ -2,13 +2,13 @@
 
 package Validation::Class;
 {
-    $Validation::Class::VERSION = '7.13';
+    $Validation::Class::VERSION = '7.15';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.13';    # VERSION
+our $VERSION = '7.15';    # VERSION
 
 use Module::Find;
 use Carp 'confess';
@@ -774,7 +774,7 @@ Validation::Class - Self-Validating Object System and Data Validation Framework
 
 =head1 VERSION
 
-version 7.13
+version 7.15
 
 =head1 SYNOPSIS
 
@@ -1409,6 +1409,18 @@ documentation.
 
 See L<Validation::Class::Prototype/get_errors> for full documentation.
 
+=head2 get_fields
+
+    $self->get_fields;
+
+See L<Validation::Class::Prototype/get_fields> for full documentation.
+
+=head2 get_params
+
+    $self->get_params;
+
+See L<Validation::Class::Prototype/get_params> for full documentation.
+
 =head2 fields
 
     $self->fields;
@@ -1479,12 +1491,36 @@ See L<Validation::Class::Prototype/report_unknown> for full documentation.
 
 See L<Validation::Class::Prototype/reset_errors> for full documentation.
 
+=head2 reset_fields
+
+    $self->reset_fields;
+
+See L<Validation::Class::Prototype/reset_fields> for full documentation.
+
+=head2 reset_params
+
+    $self->reset_params;
+
+See L<Validation::Class::Prototype/reset_params> for full documentation.
+
 =head2 set_errors
 
     $self->set_errors;
 
 See L<Validation::Class::Prototype/set_errors> for full documentation.
 
+=head2 set_fields
+
+    $self->set_fields;
+
+See L<Validation::Class::Prototype/set_fields> for full documentation.
+
+=head2 set_params
+
+    $self->set_params;
+
+See L<Validation::Class::Prototype/set_params> for full documentation.
+
 =head2 set_method
 
     $self->set_method;
